{% load i18n %}
<tr class="criterion" id="criterion-{{id}}">    
    <td>
        <input type="text" size="2" class="position" name="position-{{id}}" value="{{position}}" />
    </td>
    
    <td>
        <select class="criterion-type" name="type-{{id}}">
            <option value="country" selected="selected">{% trans 'Country' %}</option>
            <option value="combinedlengthandgirth">{% trans 'Combined length and girth' %}</option>
            <option value="payment_method">{% trans 'Payment method' %}</option>
            <option value="price">{% trans 'Price' %}</option>
            <option value="height">{% trans 'Height' %}</option>
            <option value="length">{% trans 'Length' %}</option>
            <option value="shipping_method">{% trans 'Shipping method' %}</option>
            <option value="width">{% trans 'Width' %}</option>
            <option value="weight">{% trans 'Weight' %}</option>
        </select>
    </td>
    <td>
        {% include "manage/criteria/selection_operators.html" %}
    </td>
    <td>
        <select name="value-{{id}}"
                multiple="multiple"
                size="5">
            {% for country in countries %}
                <option value="{{country.id}}" {% if country.selected %}selected="selected"{% endif %}>{{country.name}}</option>
            {% endfor %}    
        </select>
    </td>
    <td>
        <a class="criterion-add-button"
           href="{% url lfs_add_criterion %}">
            <img src="{{MEDIA_URL}}lfs/icons/add.png"
                 alt="Add" />
        </a>
        <a class="criterion-delete-button">
            <img src="{{MEDIA_URL}}lfs/icons/delete.png"
                 alt="Delete" />        
        </a>
    </td>
</tr>